@@ -1,8 +1,28 @@
+GtkWidget *win;
 struct stat buf;
 DIR *dir;
 struct dirent *dirpointer;
 GtkWidget *dialog=NULL;
-gchar *com_com=NULL;
+gchar *last_app_standing;
+gchar *playlist_dir;
+
+char *mp3_play_status;
+int mp3_default;
+
+char *sh_exec_status;
+int sh_exec_default;
+
+char *picviewer_status;
+int picviewer;
+
+char *mode_status;
+int fast_mode;
+
+int center_label;
+int toolbar_on_top;
+int ff_mode;
+int bookmarkview;
+
 #ifndef DESKYPPLET_H
 #define DESKYPPLET_H
 
@@ -22,7 +42,6 @@ G_BEGIN_DECLS
 #define MAX_Y_SIZE 420
 
 #define SETTINGS_PATH	".deskypplet"
-/*#define EXISTING_NOTE	"note"*/
 #define PREFS_FILE	"deskypplet.conf"
 
 #define DEFAULT_COLOR		"#ffff00"
@@ -87,9 +106,10 @@ typedef struct
 	GtkWidget *label_evbox;
 	GtkWidget *folder_up_evbox;
 	GtkWidget *folder_up_image;
-	GtkWidget *folder_home_evbox;
 	GtkWidget *folder_home_image;
-		
+	GtkWidget *folder_home_evbox;
+	GtkWidget *folder_home_togglebox;
+			
 	GtkTextBuffer *buffer;
 	
 	GdkColor color;
@@ -104,10 +124,20 @@ typedef struct
 	
 	gfloat bg_alpha;
 
+    gchar *bookmarks_name_size;
+	gchar *files_name_size;
+	gchar *title_font_size;
+	
 	gint applet_x_size;
 	gint applet_y_size;
 	gint *locked;
-	  
+	gint icon_x_size;
+	gint icon_y_size;
+	gint icon_label_x_size;
+	gint icon_label_y_size;
+	gint title_height;
+	gint title_button_size;
+	 
 } YNCtx;
 
 /*adjusting width and height not to exceed max size allowed*/
@@ -137,45 +167,73 @@ gboolean configure_applet(GtkWidget *o,YNCtx *app);
 /*create desktop widget applet and build UI*/
 void mkplugin_create_home_applet(YNCtx *app);
 void build_ui(void);
-
-void menu (void);
-
+void create_table (YNCtx *app);
 static gboolean handle_expose (GtkWidget *widget, GdkEventExpose *event);
+static gboolean handle_expose_scrollbar (GtkWidget *widget, GdkEventExpose *event);
+GdkPixbuf *get_pixbuf_folder (gchar *fullpath);
+GdkPixbuf *get_pixbuf_file (gchar *fullpath);
 
+/*help func*/
+int myComparisonFunction(const void *x, const void *y);
+gchar *g_get_free_space ( gchar * dev_path);
+gchar *g_get_capacity ( gchar * dev_path);
+
+/*----*/
+void menu (void);
+void menu_folders (gchar *fullpath);
+void menu_files (gchar *fullpath);
+
+/*mode switches*/
+void toggle_mp3_play (void);
+void toggle_picviewer (void);
+void toggle_exec_sh (void);
+void toggle_mode (void);
+void toggle_bookmark_view (GObject *o,GdkEventButton *event,YNCtx *app);
 
 /*handle rotation*/
 static gboolean is_portrait ();
 void on_orientation_changed(GdkScreen *screen,YNCtx *app);
 
-void folder_down (GObject *o,GdkEventButton *event,gchar *fullpath);
-void bookmark (gpointer button,gchar *fullpath);
-void custom_com (gpointer button,gchar *com_do);
-void term_her (void);
-void book_this (void);
-
+/*navigation*/
+void change_folder (gchar *fullpath);
+void change_folder2 (gpointer button,gchar *fullpath);
 void go_folder_up (GObject *o,GdkEventButton *event,YNCtx *app);
-void go_folder_home (GObject *o,GdkEventButton *event,YNCtx *app);
-void create_table (YNCtx *app);
-void yppletactions(YNCtx *app);
-void do_it (void);
-int myComparisonFunction(const void *x, const void *y);
-gchar *g_get_free_space ( gchar * dev_path);
-gchar *g_get_capacity ( gchar * dev_path);
+
+/*action*/
+void icon_tap (GObject *o,GdkEventButton *event,gchar *fullpath);
+void icon_tap_advanced (GObject *o,GdkEventButton *event,gchar *fullpath);
+void handle_mime (gchar *fullpath);
+void bookmark_tapped (GObject *o,GdkEventButton *event,gchar *fullpath);/*gpointer button*/
+void custom_com (gpointer button,gchar *com_do);
+void open_file (gpointer button,gchar *fullpath);
+
+/*void term_her (void);*/
+void check_config (void);
+
+/*additional features*/
+void pic_view(GdkPixbuf *pixbuf);
+void end_picview (void);
+static gboolean is_mp3_folder (gchar *fullpath);
+void play_folder (gchar *fullpath);
+void book_this (GObject *o,GdkEventButton *event);
+void call_help (void);
+void show_bookmarks (YNCtx *app);
+
 /*widget style to unset sapwood engine for scrollbar.
 RGBA colormap has conflict with default theme's PNGs*/
 gchar *scroll_style="style \"my-style\" \
 { \
-	bg[NORMAL] = \"#5A5A5A\" \
+	bg[NORMAL] = \"#FAFAFA\" \
 	bg[ACTIVE] = \"#202020\" \
-        GtkRange::stepper_size = 60 \
+        GtkRange::stepper_size = 50 \
         GtkRange::stepper_spacing = 0 \
         GtkRange::trough_border = 0 \
-        GtkRange::slider_width = 40 \
-        GtkRange::draw_trough_under_steppers = 1 \
+        GtkRange::slider_width = 25 \
+        GtkRange::draw_trough_under_steppers = 0 \
         GtkRange::draw_trough = 1 \
         GtkRange::arrow_displacement_x = 0 \
         GtkRange::arrow_displacement_y = 0 \
-        GtkRange::autodimmed_steppers = 1 \
+        GtkRange::autodimmed_steppers = 0 \
         GtkScrollbar::min-slider-length = 32 \
 	GtkScrollbar::scrollbar-spacing = 0 \
         GtkRange::activate-slider = 1 \
